@@ -92,7 +92,7 @@ read_config (gchar *option)
 void
 remember_fe_cb (gpointer data, guint action, GtkWidget *w )
 {
-  if (GTK_CHECK_MENU_ITEM(w)->active)
+  if (gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (w)))
     write_config ("remember-frontend", "yes");
   else
     write_config ("remember-frontend", "no");
@@ -111,7 +111,7 @@ remember_fe_cb (gpointer data, guint action, GtkWidget *w )
 void
 show_libgnome_missing_alert (gpointer data, guint action, GtkWidget *w )
 {
-  if (GTK_CHECK_MENU_ITEM(w)->active)
+  if (gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (w)))
     write_config ("libgnome-alert", "yes");
   else
     write_config ("libgnome-alert", "no");
