@@ -50,17 +50,15 @@ extern gint errno;
 static gchar *debconf_engine = NULL; // What debconf engine is installed (cdebconf | debconf)
 static gchar *debconfcmd     = NULL; // Which dpkg-reconfigure (from debconf or cdebconf)
 
-int inline file_exists(char *file);
-
 /* stores information about available front ends */
 // Web frontend can work if any of web browsers is installed (www-browser virtual package)
 
 // debconf frontends
 dfrontend dfes[] = {
-                     {"gnome", FALSE, "libgtk2-perl", NULL},
-                     {"kde", FALSE, "libqt-perl", NULL},
+                     {"gnome", FALSE, "libgtk3-perl", NULL},
+                     {"kde", FALSE, "debconf-kde-helper", NULL},
                      {"dialog", TRUE, "dialog", "whiptail"},
-                     {"readline", TRUE, "libterm-readline-gnu-perl", "libreadline4"},
+                     {"readline", TRUE, "libterm-readline-gnu-perl", NULL},
                      {"editor", TRUE, NULL, NULL},
                      {"web", FALSE, NULL, NULL}, // virtual package "www-browser"
                      {NULL, FALSE}
@@ -85,9 +83,9 @@ gchar *frontend; // Last frontend used
  */
 void get_debconf()
 {
-  char *file = NULL;
+  gchar *query[] = { "/usr/bin/dpkg-query", "--status", "cdebconf", NULL };
   gchar *msg;
-  int ret;
+  gint ret;
 
   msg = g_strdup_printf (_("Checking whether\n%s\nis installed"),
                          "cdebconf");
@@ -95,8 +93,9 @@ void get_debconf()
   while (gtk_events_pending())
     gtk_main_iteration();
   g_free (msg);
-  file = g_strdup_printf ("/var/lib/dpkg/info/%s.list", "cdebconf");
-  ret = file_exists(file);
+  g_spawn_sync (NULL, query, NULL,
+                G_SPAWN_STDOUT_TO_DEV_NULL | G_SPAWN_STDERR_TO_DEV_NULL,
+                NULL, NULL, NULL, NULL, &ret, NULL);
   if (ret == 0)
     {
       debconf_engine = g_strdup_printf("cdebconf");
@@ -115,11 +114,6 @@ void get_debconf()
       return;
     }
 }
-int inline file_exists(char *file)
-{
-  struct stat st;
-  return stat(file, &st);
-}
 
 /**
  * check_missing:
@@ -133,7 +127,6 @@ int inline file_exists(char *file)
 
 int check_missing (gchar *fe)
 {
-  char *file = NULL;
   gchar *msg;
   gint i;
   gint ret ;
@@ -151,8 +144,10 @@ int check_missing (gchar *fe)
   while (gtk_events_pending())
     gtk_main_iteration();
   g_free (msg);
-  file = g_strdup_printf ("/var/lib/dpkg/info/%s.list", dfes[i].dep1);
-  ret = file_exists(file);
+  gchar *query[] = { "/usr/bin/dpkg-query", "--status", dfes[i].dep1, NULL };
+  g_spawn_sync (NULL, query, NULL,
+                G_SPAWN_STDOUT_TO_DEV_NULL | G_SPAWN_STDERR_TO_DEV_NULL,
+                NULL, NULL, NULL, NULL, &ret, NULL);
   if ( (ret != 0) && (dfes[i].dep2 != NULL) )
     {
       msg = g_strdup_printf (_("Checking whether\n%s\nis installed"),
@@ -161,10 +156,13 @@ int check_missing (gchar *fe)
       while (gtk_events_pending())
         gtk_main_iteration();
       g_free (msg);
-      file = g_strdup_printf ("/var/lib/dpkg/info/%s.list", dfes[i].dep2);
-      ret = file_exists(file);
+      gchar *query[] = { "/usr/bin/dpkg-query", "--status",
+                         dfes[i].dep2, NULL };
+      g_spawn_sync (NULL, query, NULL,
+                    G_SPAWN_STDOUT_TO_DEV_NULL | G_SPAWN_STDERR_TO_DEV_NULL,
+                    NULL, NULL, NULL, NULL, &ret, NULL);
     }
-  g_free (file);
+
   return ret;
 }
 
@@ -182,9 +180,8 @@ get_frontends (GtkWidget *menu)
 {
   GSList *group = NULL;
   GtkWidget *item;
-  GtkTooltips *tooltips;
-  gchar *message;
-  GtkItemFactory *item_factory = gtk_item_factory_from_widget (menu);
+  GtkWidget *opts_menu;
+  gchar *message, *tooltip;
   gchar *fe, *remember_fe, *str_item, *libgnome_alert;
   gint i;
 
@@ -209,7 +206,6 @@ get_frontends (GtkWidget *menu)
     frontend = g_ascii_strdown (dfes[0].name, -1);
 
   g_free (remember_fe);
-  tooltips = gtk_tooltips_new ();
   get_debconf();
   if (strcmp(debconf_engine, "debconf") == 0)
     {
@@ -219,10 +215,11 @@ get_frontends (GtkWidget *menu)
           item = gtk_radio_menu_item_new_with_label (group, str_item);
           group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (item));
           gtk_widget_show (item);
-          gtk_container_add (GTK_CONTAINER (gtk_item_factory_get_widget (item_factory,
-                                            _("/Options"))), item);
-          gtk_tooltips_set_tip (tooltips, item, g_strconcat( _("Select "), str_item, NULL),
-                                NULL);
+          opts_menu = g_object_get_data (G_OBJECT (menu), "frontends");
+          gtk_menu_shell_append (GTK_MENU_SHELL (opts_menu), item);
+          tooltip = g_strconcat (_("Select "), str_item, NULL);
+          gtk_widget_set_tooltip_text (item, tooltip);
+          g_free (tooltip);
           g_free(str_item);
 
           if (check_missing(dfes[i].name) == 0)
@@ -252,7 +249,8 @@ get_frontends (GtkWidget *menu)
                   gk_dialog_for_gconf ("libgnome-alert", message);
 
                 }
-              gtk_widget_set_state(item,GTK_STATE_INSENSITIVE);
+              gtk_widget_set_state_flags (item, GTK_STATE_FLAG_INSENSITIVE,
+                                          FALSE);
             }
         }
     }
@@ -264,10 +262,11 @@ get_frontends (GtkWidget *menu)
           item = gtk_radio_menu_item_new_with_label (group, str_item);
           group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (item));
           gtk_widget_show (item);
-          gtk_container_add (GTK_CONTAINER (gtk_item_factory_get_widget (item_factory,
-                                            _("/Options"))), item);
-          gtk_tooltips_set_tip (tooltips, item, g_strconcat( _("Select "), str_item, NULL),
-                                NULL);
+          opts_menu = g_object_get_data (G_OBJECT (menu), "frontends");
+          gtk_menu_shell_append (GTK_MENU_SHELL (opts_menu), item);
+          tooltip = g_strconcat (_("Select "), str_item, NULL);
+          gtk_widget_set_tooltip_text (item, tooltip);
+          g_free (tooltip);
           g_free(str_item);
 
           g_signal_connect ((gpointer) item, "activate",
